AsScaleAnimation class

Animates the child

using TweenAnimationBuilder

Inheritance

Constructors

AsScaleAnimation({Key? key, required Widget child, double begin = 0.4, double end = 1, double intervalStart = 0, double intervalEnd = 1, Duration duration = const Duration(milliseconds: 1000), Curve curve = Curves.fastOutSlowIn})
const

Properties

begin → double
Animate from value
final
child → Widget
This widget will be animated
final
curve → Curve
Animation Curve
final
duration → Duration
Animation Duration
final
end → double
Animate to value
final
hashCode → int
The hash code for this object.
no setterinherited
intervalEnd → double
Animation delay
final
intervalStart → double
Animation delay
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited